summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThom May <thom@chef.io>2018-05-16 17:24:04 +0100
committerThom May <thom@chef.io>2018-05-16 17:24:04 +0100
commite4f2e93f48b250ecc024346a4b29c0bcb9c71a35 (patch)
tree04fe6da2ca308272ef9304c55775145466ddcbc6
parent02a203fd549d5261e55d8e7f9aee1354d8bce5d4 (diff)
downloadchef-tm/dont_mind_state.tar.gz
we removed the state default property in 13tm/dont_mind_state
Signed-off-by: Thom May <thom@chef.io>
-rw-r--r--.expeditor/config.yml3
-rw-r--r--lib/chef/property.rb4
2 files changed, 5 insertions, 2 deletions
diff --git a/.expeditor/config.yml b/.expeditor/config.yml
index 21d8ca10e6..ee2ff102d0 100644
--- a/.expeditor/config.yml
+++ b/.expeditor/config.yml
@@ -23,6 +23,9 @@ github:
# The file where our CHANGELOG is kept. This file is updated automatically with
# details from the Pull Request via the `built_in:update_changelog` merge_action.
changelog_file: "CHANGELOG.md"
+ # This will trigger an Omnibus build with EXPIRE_CACHE enabled after
+ # a pull request is merged into the release branch.
+ enable_expire_cache: true
# The tag format to use (e.g. v1.0.0)
version_tag_format: "v{{version}}"
# The Github Team primarily responsible for handling incoming Pull Requests.
diff --git a/lib/chef/property.rb b/lib/chef/property.rb
index 776b64bdc8..cdabf27be5 100644
--- a/lib/chef/property.rb
+++ b/lib/chef/property.rb
@@ -657,9 +657,9 @@ class Chef
# as needed.
return if Chef::Resource.properties.keys.include?(name)
# Special case for `supports` as it was moved in Chef 13 and this is causing
# some user confusion in cookbooks that need to support both 12 and 13.
- return if name.to_s == "supports"
+ return if %w{ supports state }.include? name.to_s
# Emit the deprecation.
resource_name = declared_in.respond_to?(:resource_name) ? declared_in.resource_name : declared_in
@@ -657,9 +657,9 @@ class Chef
# as needed.
return if Chef::Resource.properties.keys.include?(name)
- # Special case for `supports` as it was moved in Chef 13 and this is causing
+ # Special case for `supports` and `state` as they were moved in Chef 13 and this is causing
# some user confusion in cookbooks that need to support both 12 and 13.